@@ -1,4 +1,4 @@
-# $Id: Exception.pm,v 1.5 2006/05/15 08:37:07 tonyb Exp $
+# $Id: Exception.pm,v 1.6 2006/06/16 15:20:56 tonyb Exp $
 #
 # Copyright (c) 2002-2005 Cunningham & Cunningham, Inc.
 # Released under the terms of the GNU General Public License version 2 or later.
@@ -10,12 +10,11 @@ package Test::C2FIT::Exception;
 use Error qw( :try );
 use base 'Error::Simple';
 
-sub getMessage
-{
-	my $self = shift;
-	my $message = $self->stringify();
-	chomp $message;
-	return $message;
+sub getMessage {
+    my $self    = shift;
+    my $message = $self->stringify();
+    chomp $message;
+    return $message;
 }
 
 # Keep Perl happy.
