@@ -1,4 +1,4 @@
-# $Id: ParseException.pm,v 1.5 2006/05/15 08:37:07 tonyb Exp $
+# $Id: ParseException.pm,v 1.6 2006/06/16 15:20:56 tonyb Exp $
 #
 # Copyright (c) 2002-2005 Cunningham & Cunningham, Inc.
 # Released under the terms of the GNU General Public License version 2 or later.
@@ -9,10 +9,9 @@
 package Test::C2FIT::ParseException;
 use base 'Test::C2FIT::Exception';
 
-sub getErrorOffset
-{
-	my $self = shift;
-	return $self->value();
+sub getErrorOffset {
+    my $self = shift;
+    return $self->value();
 }
 
 # Keep Perl happy.
